namespace Eco.Mods.TechTree
{
    // [DoNotLocalize]
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using Eco.Gameplay.Blocks;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Economy;
    using Eco.Gameplay.Housing;
    using Eco.Gameplay.Interactions;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Minimap;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Property;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Gameplay.Pipes.LiquidComponents;
    using Eco.Gameplay.Pipes.Gases;
    using Eco.Gameplay.Systems.Tooltip;
    using Eco.Shared;
    using Eco.Shared.Math;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Shared.Items;
    using Eco.Gameplay.Pipes;
    using Eco.World.Blocks;
    
    [Serialized]
    [RequireComponent(typeof(OnOffComponent))]                   
    [RequireComponent(typeof(PropertyAuthComponent))]
    [RequireComponent(typeof(MinimapComponent))]                
    [RequireComponent(typeof(PowerGridComponent))]              
    [RequireComponent(typeof(PowerGeneratorComponent))]         
    [RequireComponent(typeof(HousingComponent))]           
    public partial class ModernFlatSolarPanelsObject : 
        WorldObject,    
        IRepresentsItem
    {
        public override LocString DisplayName { get { return Localizer.DoStr("Modern Flat SolarPanels"); } } 

        public virtual Type RepresentedItemType { get { return typeof(ModernFlatSolarPanelsItem); } } 

        static ModernFlatSolarPanelsObject()
        {
            WorldObject.AddOccupancy<ModernFlatSolarPanelsObject>(new List<BlockOccupancy>(){
                new BlockOccupancy(new Vector3i(0, 0, 0), typeof(BuildingWorldObjectBlock)),
                new BlockOccupancy(new Vector3i(0, 1, 0), typeof(BuildingWorldObjectBlock)),
                new BlockOccupancy(new Vector3i(0, 2, 0), typeof(BuildingWorldObjectBlock)),
				new BlockOccupancy(new Vector3i(0, 3, 0), typeof(BuildingWorldObjectBlock)),
	            new BlockOccupancy(new Vector3i(-1, 0, 0), typeof(BuildingWorldObjectBlock)),
                new BlockOccupancy(new Vector3i(-1, 1, 0), typeof(BuildingWorldObjectBlock)),
                new BlockOccupancy(new Vector3i(-1, 2, 0), typeof(BuildingWorldObjectBlock)),
				new BlockOccupancy(new Vector3i(-1, 3, 0), typeof(BuildingWorldObjectBlock)),
	            new BlockOccupancy(new Vector3i(-2, 0, 0), typeof(BuildingWorldObjectBlock)),
                new BlockOccupancy(new Vector3i(-2, 1, 0), typeof(BuildingWorldObjectBlock)),
                new BlockOccupancy(new Vector3i(-2, 2, 0), typeof(BuildingWorldObjectBlock)),
				new BlockOccupancy(new Vector3i(-2, 3, 0), typeof(BuildingWorldObjectBlock)),
				new BlockOccupancy(new Vector3i(1, 0, 0), typeof(BuildingWorldObjectBlock)),
				new BlockOccupancy(new Vector3i(1, 1, 0), typeof(BuildingWorldObjectBlock)),
				new BlockOccupancy(new Vector3i(1, 2, 0), typeof(BuildingWorldObjectBlock)),
				new BlockOccupancy(new Vector3i(1, 3, 0), typeof(BuildingWorldObjectBlock)),
				new BlockOccupancy(new Vector3i(2, 0, 0), typeof(BuildingWorldObjectBlock)),
				new BlockOccupancy(new Vector3i(2, 1, 0), typeof(BuildingWorldObjectBlock)),
				new BlockOccupancy(new Vector3i(2, 2, 0), typeof(BuildingWorldObjectBlock)),
				new BlockOccupancy(new Vector3i(2, 3, 0), typeof(BuildingWorldObjectBlock)),
                });
        }

        protected override void Initialize()
        {

            this.GetComponent<MinimapComponent>().Initialize(Localizer.DoStr("Power"));                
            this.GetComponent<PowerGridComponent>().Initialize(30, new ElectricPower());        
            this.GetComponent<PowerGeneratorComponent>().Initialize(800);                       
            this.GetComponent<HousingComponent>().Set(ModernFlatSolarPanelsItem.HousingVal);                                

        }

        public override void Destroy()
        {
            base.Destroy();
        }
       
    }

    [Serialized]
    public partial class ModernFlatSolarPanelsItem :
        WorldObjectItem<ModernFlatSolarPanelsObject> 
    {
        public override LocString DisplayName { get { return Localizer.DoStr("Modern Flat SolarPanels"); } } 
        public override LocString DisplayDescription  { get { return Localizer.DoStr("Generates electrical power from the sun! It also stores energy to work at night."); } }

        static ModernFlatSolarPanelsItem()
        {
            
        }

        [TooltipChildren] public HousingValue HousingTooltip { get { return HousingVal; } }
        [TooltipChildren] public static HousingValue HousingVal { get { return new HousingValue() 
                                                {
                                                    Category = "Industrial",
                                                    TypeForRoomLimit = "", 
        };}}
        
        [Tooltip(8)] private LocString PowerProductionTooltip  { get { return new LocString(string.Format(Localizer.DoStr("Produces: {0}w"), Text.Info(800))); } } 
    }

    [RequiresSkill(typeof(ElectronicsSkill), 0)]      
    public partial class ModernFlatSolarPanelsRecipe : Recipe
    {
        public ModernFlatSolarPanelsRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<ModernFlatSolarPanelsItem>(),
            };

            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<SteelItem>(typeof(ElectronicsSkill), 50, ElectronicsSkill.MultiplicativeStrategy, typeof(ElectronicsLavishResourcesTalent)),
                new CraftingElement<ServoItem>(typeof(ElectronicsSkill), 22, ElectronicsSkill.MultiplicativeStrategy, typeof(ElectronicsLavishResourcesTalent)),
                new CraftingElement<CircuitItem>(typeof(ElectronicsSkill), 20, ElectronicsSkill.MultiplicativeStrategy, typeof(ElectronicsLavishResourcesTalent)),          
            };
            this.ExperienceOnCraft = 25;  
            this.CraftMinutes = CreateCraftTimeValue(typeof(ModernFlatSolarPanelsRecipe), Item.Get<ModernFlatSolarPanelsItem>().UILink(), 50, typeof(ElectronicsSkill), typeof(ElectronicsFocusedSpeedTalent), typeof(ElectronicsParallelSpeedTalent));    
            this.Initialize(Localizer.DoStr("Modern Flat SolarPanels"), typeof(ModernFlatSolarPanelsRecipe));
            CraftingComponent.AddRecipe(typeof(ElectronicsAssemblyObject), this);
        }
    }
}